@@ -40,7 +40,7 @@ const SubmissionItemContainer = styled.li`
   padding: 5px 12px;
   height: 16px;
 
-  font-family: 'Noto Sans KR';
+  font-family: var(--jp-ui-font-family);
   font-style: normal;
   font-size: 12px;
   line-height: 16px;
@@ -63,7 +63,7 @@ const ItemLoad = styled.button`
   all: unset;
   cursor: pointer;
 
-  font-family: 'Noto Sans KR';
+  font-family: var(--jp-ui-font-family);
   font-style: normal;
   font-weight: 700;
   font-size: 12px;
@@ -78,7 +78,7 @@ const ItemTime = styled.span`
 
   text-align: right;
 
-  font-family: 'Noto Sans KR';
+  font-family: var(--jp-ui-font-family);
   font-style: normal;
   font-weight: 400;
   font-size: 12px;
